@@ -1,47 +1,31 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
-// -*- c++ -*-
-#ifndef BASICFRAME_H
+#ifndef BASICFRAME_H		// -*- c++ -*-
 #define BASICFRAME_H
-
-#include "units.h"
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include "pagent.h"
 #include "fileerrors.h"
 #include <iostream>
+#include <libxml++/libxml++.h>
 
-namespace Error
-{
+namespace Error {
   struct Frame_Type: public File {
     Frame_Type(const string& msg) : File("Frame-type error: " + msg) {}
   };
 }
 
-class Basic_Frame: public Pagent
-{
-protected:
-  FLength width, height;
-
+class Basic_Frame: public Pagent {
 public:
-  Basic_Frame(Group *parent, FLength w, FLength h, const std::string& name);
-  Basic_Frame(Group *parent, const XMLNode& node);
+  Basic_Frame(Group *parent, float w, float h, const Glib::ustring& name);
+  Basic_Frame(Group *parent, const xmlpp::Element& node);
   virtual ~Basic_Frame();
   
-  virtual XMLNode *save();
-  virtual void print(std::ostream &out);
-
-  Box get_box() const;
-
-  virtual void move_reshape_box(int box, Vector v);
-
-  //  virtual void act_on_zoom_factor_change() {};
-
-  void set_size(FLength w, FLength h);
-  virtual FLength get_width() const {return width;}
-  virtual FLength get_height() const {return height;}
+  virtual xmlpp::Element *save(xmlpp::Element& parent_node) const;
+  virtual void print(std::ostream &out, bool grayscale = false) const;
+  
+  Boundary get_box() const;
+  Boundary get_obstacle_boundary() const;
   
-  Boundary* getObstacleBoundary() const;
-
   // Errors reported by generate_picture:
   // ASSOCIATION - failed to open associated file
   //  GENERATION - general error (missing program, corrupted file, et cetera)
@@ -54,7 +38,7 @@ public:
     ~Gen_Pic_Error() throw() {}
   };
   
-  void draw_content_error(View& view, const Gdk_Pixmap &pixmap);
+  void draw_content_error(View& view, Glib::RefPtr<const Gdk::Pixmap> pixmap);
   void draw_content_wait(View& view);
   void draw_content_missing(View& view);
   void draw_content_broken(View& view);
