@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "errordialog.h"
 #include "globals.h"
@@ -25,26 +25,20 @@ void Error_Dialog::view(const std::string& message) {
 }
 
 Error_Dialog::Error_Dialog(Gtk::Window &parent)
-  :ok_button(" OK ")
+  :MessageDialog(parent, "", Gtk::MESSAGE_ERROR,
+		 Gtk::BUTTONS_OK, true, false)
+		 
 {
-  set_transient_for(parent);
-  set_border_width(border_width);
-  set_modal(true);
-  set_title("Error");
-  set_policy(false, false, true);
-  get_action_area()->pack_start(ok_button, true, false, 0);
-  get_vbox()->pack_start(message_, true, true, 0);
-  // Don't use safeslot here, since it uses Error_Dialog!  Instead, make the
-  // ok function simple so it doesn't emit any exception.
-  ok_button.clicked.connect(slot(this, &Error_Dialog::ok));
+  if(get_action_area()){
+    Gtk::Button *ok_button = 
+      dynamic_cast<Gtk::Button*>
+      (get_action_area()->children().front().get_widget());
+    if(ok_button)
+      ok_button->signal_clicked().connect(slot(*this, &Error_Dialog::hide));
+  }
 }
 
 void Error_Dialog::show_message(const std::string& message) {
-  message_.set_text(message);
+  set_message(message);
   show_all();
 }
-
-int Error_Dialog::delete_event_impl(GdkEventAny*) {
-  ok(); 
-  return true;
-}
