@@ -1,13 +1,14 @@
 ///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "imagemeta.h"
 #include "imageframe.h"
 #include "propbase.h"
-#include "streamdialog.h"
-#include <gtk--/label.h>
+#include "widget/filesel.h"
+#include "widget/wmisc.h"
+#include <gtkmm/label.h>
 
-Pagent* ImageMeta::load(const XMLNode& node, Group* parent){
+Pagent* ImageMeta::load(const xmlpp::Element& node, Group* parent){
   return new Image_Frame(parent, node);
 }
 
@@ -18,12 +19,15 @@ Pagent* ImageMeta::load(const XMLNode& node, Group* parent){
 class PropImage : public GenericProp<Image_Frame> {
 public:
   PropImage()
-    :GenericProp<Image_Frame>("EPS", 4, 3),
-    l_fname("Filename:"),
-    e_fname("Associated File")
+    : GenericProp<Image_Frame>("_EPS"),
+     e_fname("Associated File")
     {
-      attach(l_fname, 0, 1, 0, 1, 0, 0);
-      attach(e_fname, 1, 2, 0, 1, GTK_FILL | GTK_EXPAND, 0);
+      Gtk::Box *line = manage(new Gtk::HBox(false, double_space));
+      Gtk::Label *label = manage(new Gtk::Label("_Filename:", 0.0, 0.5, true));
+      label->set_mnemonic_widget(e_fname);
+      line->pack_start(*label, Gtk::PACK_SHRINK);
+      line->pack_start(e_fname);
+      pack_start(*line, Gtk::PACK_SHRINK);
       set_sensitive(false);
       update();
     }
@@ -40,7 +44,6 @@ public:
       object->set_association(e_fname.entry.get_text());
   }
 private:
-  Gtk::Label l_fname;
   File_Entry e_fname;
 };
 
