@@ -1,14 +1,11 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
-// -*- c++ -*-
-#ifndef PAPER_SIZES_H
+#ifndef PAPER_SIZES_H		// -*- c++ -*-
 #define PAPER_SIZES_H
-
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include <string>
 #include <map>
 #include <stdexcept>
-#include "units.h"
 
 namespace Error
 {
@@ -28,14 +25,14 @@ public:
 
   class Size
   {
-    FLength width, height;
+    float width, height;
   public:
-    Size(FLength w, FLength h)
+    Size(float w, float h)
     {width=w; height=h;}
     Size()
     {width=-1; height=-1;}
-    FLength get_width(Orientation o) const {return o==PORTRAIT?width:height;}
-    FLength get_height(Orientation o) const {return o==PORTRAIT?height:width;}
+    float get_width(Orientation o) const {return o==PORTRAIT?width:height;}
+    float get_height(Orientation o) const {return o==PORTRAIT?height:width;}
   };
 
   std::map<std::string, Size> sizes;
