@@ -1,22 +1,24 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
 #ifndef PIXBUFTRANSFORMATOR_H	// -*- c++ -*-
 #define PIXBUFTRANSFORMATOR_H
-#include "widget/pixbufwrap.h"
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include "view.h"
+#include <gdkmm/pixbuf.h>
 
 class PixbufTransformator : public SigC::Object {
 public:
-  PixbufTransformator(const Pixbuf& src, const View& v,  const Matrix& m);
+  PixbufTransformator(Glib::RefPtr<const Gdk::Pixbuf> src,
+		      const View& v,  const Matrix& m);
   ~PixbufTransformator();
   
-  const Pixbuf& getPixbuf() const { return buf; }
+  Glib::RefPtr<Gdk::Pixbuf> getPixbuf() const { return buf; }
   bool isDone() const { return is_done; }
-  gint workLine();
+  bool workLine();
 
 private:
-  Pixbuf buf, srcpix;
+  Glib::RefPtr<Gdk::Pixbuf> buf;
+  Glib::RefPtr<const Gdk::Pixbuf> srcpix;
   gint max_x, min_x, max_y, min_y;
   gint cur_y;
   bool is_done;
