@@ -1,27 +1,21 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
-// -*- c++ -*-
-#ifndef PROCESSMAN_H
+#ifndef PROCESSMAN_H		// -*- c++ -*-
 #define PROCESSMAN_H
-
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include <map>
 #include <string>
-#include <sigc++/basic_signal.h>
+#include <sigc++/object.h>
 #include <sys/types.h>
-#include <gtk--/main.h>
+#include <gtkmm/main.h>
 
-struct Process
-{
+struct Process {
   std::string command_line;
-  Process(std::string line) :command_line(line)
-  {}
-  Process() :command_line("")
-  {}
+  Process(std::string line) :command_line(line) {}
+  Process() :command_line("") {}
 };
 
-class Process_Manager: public SigC::Object
-{
+class Process_Manager: public SigC::Object {
 public:
   // Signal that a process has stopped,
   // attach process id, a bool to signify normal termination
@@ -33,15 +27,30 @@ public:
   pid_t start(std::string command);
   bool stop(pid_t pid);
   std::string find_new_name();
-  bool delete_file(std::string);
   Process *get_process(pid_t pid);
   bool stop_all();
-  gint run_check();
+  bool run_check();
   int system(std::string);
+
 private:
   typedef std::map<pid_t, Process> Processes;
   Processes processes;
   const std::string filename_template;
 };
 
+
+// Creates a temp file and deletes it in the destructor
+class Tempfile {
+public:
+  Tempfile(Process_Manager &procman) : filename(procman.find_new_name()) {}
+  const std::string &get_filename() const {return filename;}
+  ~Tempfile();
+private:
+  std::string filename;
+  Tempfile(const Tempfile&);
+  Tempfile();
+  void operator = (const Tempfile&);
+
+};
+
 #endif
