@@ -1,19 +1,19 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
 #ifndef PROPBASE_H		// -*- c++ -*-
 #define PROPBASE_H
-#include <gtk--/table.h>
-#include <gtk--/label.h>
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
+#include <gtkmm/box.h>
+#include <gtkmm/label.h>
 #include "pagent.h"
 
 // Base class for the different property sets.
 // PropertiesDialog displays one PropBase at a time, through a Gtk Notebook.
-class PropBase : public Gtk::Table {
+class PropBase : public Gtk::VBox {
 public:
   typedef std::string string;
   
-  PropBase(const string& name, int rows, int cols);
+  explicit PropBase(const string& name);
   Widget& getLabel() { return label; }
   
   virtual void update() = 0;	// Changes from object to dialog
@@ -30,8 +30,8 @@ private:
 template <class FrameC>
 class GenericProp : public PropBase {
 public:
-  GenericProp(const string& label, int rows, int cols)
-    :PropBase(label, rows, cols), object(0)
+  explicit GenericProp(const string& label)
+    :PropBase(label), object(0)
   {}
   void setObject(Pagent* pagent) {
     object = dynamic_cast<FrameC*>(pagent);
