@@ -1,10 +1,13 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
 #ifndef UTIL_FILESYS_H		// -*- c++ -*-
 #define UTIL_FILESYS_H
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include <string>
-#include <iostream>
+#include <ios>			// mode for access
+
+// Check if the specified file exists
+bool exists(const std::string& filename);
 
 // Check if the specified file can be accessed
 bool access(const std::string& filename, int mode = std::ios::in);
@@ -31,5 +34,15 @@ std::string expand_path(const std::string& filename);
 std::string relative_path(const std::string& start_path,
 			  const std::string& filename);
 
+/** unlink(2) the specified filename, throw an exception on failure. */
+void unlink(const std::string& filename);
+
+/** rmdir(2) the specified dirname, throw an exception on failure. */
+void rmdir(const std::string& dirname);
+
+/** Create a temporary directory, as mkdtemp(3).  If {tmpl_name} is relative,
+ * it is put in $TMPDIR.
+ */
+std::string mkdtemp(const std::string& tmpl_name);
 
 #endif
