@@ -1,14 +1,23 @@
 ///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "stringutil.h"
-#include <stdlib.h>
-// #include <unistd.h>
+#include <cstdlib>
 #include <cctype>
 
+template<> bool to<bool>(const std::string& value) {
+  if(value == "true" || value == "1") return true;
+  if(value == "false" || value == "0") return false;
+  throw std::runtime_error("Bad value: \"" + value + "\" for bool");
+}
+
+template<> std::string tostr(const bool& b) {
+  return b? "true": "false";
+}
+
 bool whitespace(char c)
 {
-  return isspace(c);
+  return std::isspace(c);
 }
 
 std::string strip_whitespace(std::string s, bool front, bool back)
