@@ -1,9 +1,8 @@
-///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
-///
-// -*- c++ -*-
-#ifndef STDERR_H 
+#ifndef STDERR_H		// -*- c++ -*-
 #define STDERR_H
+///
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include <iostream>
 
 // Aliases for std::cerr that can be turned off.
@@ -15,8 +14,15 @@ struct cerr_Alias
   bool active;
 
   template<class A>
-  std::ostream &operator<<(const A &a)
-    {if(active) return std::cerr << a; else return null;}
+  std::ostream &operator<<(const A &a) {
+    if(active) { 
+      try {
+	return std::cerr << a; 
+      } catch(...) { // Glib::ustring might throw a Glib::ConvertError
+	return std::cerr << "[error in << operator]";
+	// We might want to create a smarter fallback
+      }
+    } else return null;}
 
 private:
   static std::ostream null;
