@@ -1,10 +1,10 @@
 ///
-// Copyright (C) 2002, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "pdfcanvas.hh"
 
 xml2ps::PDFCanvas::PDFCanvas(std::streambuf *buf, 
-			     const std::vector<xml2ps::PageBoundary>& pages,
+			     const xml2ps::Canvas::PageVec& pages,
 			     bool allow_extra_pages)
   : Canvas(pages, allow_extra_pages), out(buf)
 {
@@ -17,11 +17,17 @@ xml2ps::PDFCanvas::~PDFCanvas() {
 
 void xml2ps::PDFCanvas::newPage() {
   Canvas::newPage();
-  document.add_page(cur_page_->width(), cur_page_->height());
+  document.add_page(int(cur_page_->width() + 0.5), 
+		    int(cur_page_->height() + 0.5));
 }
 
-void xml2ps::PDFCanvas::setfont(const FontInfo& font) {
-  document.selectfont(font.getSize());
+void xml2ps::PDFCanvas::setgray(float gray) {
+  // Todo
+}
+
+void xml2ps::PDFCanvas::setfont(const font::FontInfo& font) {
+  Canvas::setfont(font);
+  document.selectfont(int(font.getSize() + 0.5));
 }
 
 void xml2ps::PDFCanvas::moveto(float hpos, float vpos) {
@@ -31,7 +37,7 @@ void xml2ps::PDFCanvas::moverel(float dx, float dy) {
   document.rmoveto(dx, dy);
 }
 
-void xml2ps::PDFCanvas::show(const string& text) {
+void xml2ps::PDFCanvas::show(const Glib::ustring& text) {
   //  const float ls = font_->getLetterSpacing();
   document.show(text);
 }
